"""
Setup script for QuickDownload
This file enables editable installs for older pip versions.
All configuration is in pyproject.toml.
"""

from setuptools import setup

# All configuration is in pyproject.toml
# This setup.py exists only for editable install compatibility
setup()
